@@ -5,8 +5,8 @@
 
 #include "ev-document-type-builtins.h"
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-annotation.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-annotation.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-annotation.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-annotation.h"
 GType
 ev_annotation_type_get_type (void)
 {
@@ -17,6 +17,7 @@ ev_annotation_type_get_type (void)
       { EV_ANNOTATION_TYPE_UNKNOWN, "EV_ANNOTATION_TYPE_UNKNOWN", "unknown" },
       { EV_ANNOTATION_TYPE_TEXT, "EV_ANNOTATION_TYPE_TEXT", "text" },
       { EV_ANNOTATION_TYPE_ATTACHMENT, "EV_ANNOTATION_TYPE_ATTACHMENT", "attachment" },
+      { EV_ANNOTATION_TYPE_TEXT_MARKUP, "EV_ANNOTATION_TYPE_TEXT_MARKUP", "text-markup" },
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
@@ -56,8 +57,30 @@ ev_annotation_text_icon_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document-annotations.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document-annotations.h"
+GType
+ev_annotation_text_markup_type_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+ 
+  if (g_once_init_enter (&g_define_type_id__volatile)) {
+    static const GEnumValue values[] = {
+      { EV_ANNOTATION_TEXT_MARKUP_HIGHLIGHT, "EV_ANNOTATION_TEXT_MARKUP_HIGHLIGHT", "highlight" },
+      { EV_ANNOTATION_TEXT_MARKUP_STRIKE_OUT, "EV_ANNOTATION_TEXT_MARKUP_STRIKE_OUT", "strike-out" },
+      { EV_ANNOTATION_TEXT_MARKUP_UNDERLINE, "EV_ANNOTATION_TEXT_MARKUP_UNDERLINE", "underline" },
+      { EV_ANNOTATION_TEXT_MARKUP_SQUIGGLY, "EV_ANNOTATION_TEXT_MARKUP_SQUIGGLY", "squiggly" },
+      { 0, NULL, NULL }
+    };
+    GType g_define_type_id = \
+       g_enum_register_static (g_intern_static_string ("EvAnnotationTextMarkupType"), values);
+      
+    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+  }
+    
+  return g_define_type_id__volatile;
+}
+
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document-annotations.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document-annotations.h"
 GType
 ev_annotations_save_mask_get_type (void)
 {
@@ -68,6 +91,7 @@ ev_annotations_save_mask_get_type (void)
       { EV_ANNOTATIONS_SAVE_NONE, "EV_ANNOTATIONS_SAVE_NONE", "none" },
       { EV_ANNOTATIONS_SAVE_CONTENTS, "EV_ANNOTATIONS_SAVE_CONTENTS", "contents" },
       { EV_ANNOTATIONS_SAVE_COLOR, "EV_ANNOTATIONS_SAVE_COLOR", "color" },
+      { EV_ANNOTATIONS_SAVE_AREA, "EV_ANNOTATIONS_SAVE_AREA", "area" },
       { EV_ANNOTATIONS_SAVE_LABEL, "EV_ANNOTATIONS_SAVE_LABEL", "label" },
       { EV_ANNOTATIONS_SAVE_OPACITY, "EV_ANNOTATIONS_SAVE_OPACITY", "opacity" },
       { EV_ANNOTATIONS_SAVE_POPUP_RECT, "EV_ANNOTATIONS_SAVE_POPUP_RECT", "popup-rect" },
@@ -75,6 +99,7 @@ ev_annotations_save_mask_get_type (void)
       { EV_ANNOTATIONS_SAVE_TEXT_IS_OPEN, "EV_ANNOTATIONS_SAVE_TEXT_IS_OPEN", "text-is-open" },
       { EV_ANNOTATIONS_SAVE_TEXT_ICON, "EV_ANNOTATIONS_SAVE_TEXT_ICON", "text-icon" },
       { EV_ANNOTATIONS_SAVE_ATTACHMENT, "EV_ANNOTATIONS_SAVE_ATTACHMENT", "attachment" },
+      { EV_ANNOTATIONS_SAVE_TEXT_MARKUP_TYPE, "EV_ANNOTATIONS_SAVE_TEXT_MARKUP_TYPE", "text-markup-type" },
       { EV_ANNOTATIONS_SAVE_ALL, "EV_ANNOTATIONS_SAVE_ALL", "all" },
       { 0, NULL, NULL }
     };
@@ -87,8 +112,8 @@ ev_annotations_save_mask_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document-find.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document-find.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document-find.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document-find.h"
 GType
 ev_find_options_get_type (void)
 {
@@ -110,8 +135,8 @@ ev_find_options_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document.h"
 GType
 ev_document_load_flags_get_type (void)
 {
@@ -151,8 +176,8 @@ ev_document_error_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document-info.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-document-info.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document-info.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-document-info.h"
 GType
 ev_document_layout_get_type (void)
 {
@@ -285,8 +310,8 @@ ev_document_info_fields_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-file-exporter.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-file-exporter.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-file-exporter.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-file-exporter.h"
 GType
 ev_file_exporter_format_get_type (void)
 {
@@ -335,8 +360,8 @@ ev_file_exporter_capabilities_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-file-helpers.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-file-helpers.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-file-helpers.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-file-helpers.h"
 GType
 ev_compression_type_get_type (void)
 {
@@ -359,8 +384,8 @@ ev_compression_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-form-field.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-form-field.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-form-field.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-form-field.h"
 GType
 ev_form_field_text_type_get_type (void)
 {
@@ -423,8 +448,8 @@ ev_form_field_choice_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-link-action.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-link-action.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-link-action.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-link-action.h"
 GType
 ev_link_action_type_get_type (void)
 {
@@ -449,8 +474,8 @@ ev_link_action_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-link-dest.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-link-dest.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-link-dest.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-link-dest.h"
 GType
 ev_link_dest_type_get_type (void)
 {
@@ -478,8 +503,8 @@ ev_link_dest_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-selection.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-selection.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-selection.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-selection.h"
 GType
 ev_selection_style_get_type (void)
 {
@@ -501,8 +526,8 @@ ev_selection_style_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-transition-effect.h" */
-#include "/usr/src/ports/evince/evince-3.14.2-1.x86_64/src/evince-3.14.2/libdocument/ev-transition-effect.h"
+/* enumerations from "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-transition-effect.h" */
+#include "/usr/src/ports/evince/evince-3.18.2-1.x86_64/src/evince-3.18.2/libdocument/ev-transition-effect.h"
 GType
 ev_transition_effect_type_get_type (void)
 {
